"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnreferencedState = exports.GarbageCollectionMessageType = exports.GCNodeType = exports.defaultSweepGracePeriodMs = exports.defaultSessionExpiryDurationMs = exports.defaultInactiveTimeoutMs = exports.maxSnapshotCacheExpiryMs = exports.oneDayMs = exports.disableAutoRecoveryKey = exports.detectOutboundRoutesViaDDSKey = exports.disableDatastoreSweepKey = exports.gcVersionUpgradeToV4Key = exports.throwOnTombstoneUsageKey = exports.throwOnTombstoneLoadOverrideKey = exports.disableTombstoneKey = exports.runSessionExpiryKey = exports.gcTestModeKey = exports.runSweepKey = exports.runGCKey = exports.gcGenerationOptionName = exports.gcDisableDataStoreSweepOptionName = exports.gcDisableThrowOnTombstoneLoadOptionName = exports.nextGCVersion = exports.stableGCVersion = void 0;
/** The stable/default version of GC Data */
exports.stableGCVersion = 3;
/** The next version of GC Data, to bump to in case we need to regenerate all GC Data across all files. */
exports.nextGCVersion = 4;
/**
 * This undocumented GC Option (on ContainerRuntime Options) allows an app to disable throwing an error when tombstone
 * object is loaded (requested), merely logging a message instead.
 *
 * By default, attempting to load a Tombstoned object will result in an error.
 */
exports.gcDisableThrowOnTombstoneLoadOptionName = "gcDisableThrowOnTombstoneLoad";
/**
 * This undocumented GC Option (on ContainerRuntime Options) allows an app to enable Sweep for blobs only.
 * Only applies if enableGCSweep option is set to true.
 */
exports.gcDisableDataStoreSweepOptionName = "disableDataStoreSweep";
/**
 * This undocumented GC Option (on ContainerRuntime Options) allows configuring which documents can have Sweep enabled.
 * This provides a way to disable both Tombstone Enforcement and Sweep.
 *
 * If unset, Tombstone Enforcement + Sweep will operate as otherwise configured.
 * Otherwise, the Sweep Phase will be disabled for documents where persisted value doesn't match what is passed into this session.
 * This provides a way to disallow Sweep for old documents that may be too difficult for an app to repair,
 * in case a bug is found that violates GC's assumptions.
 *
 * @see GCFeatureMatrix (gcGeneration)
 */
exports.gcGenerationOptionName = "gcGeneration";
/** Config key to turn GC on / off. */
exports.runGCKey = "Fluid.GarbageCollection.RunGC";
/** Config key to turn GC sweep on / off. */
exports.runSweepKey = "Fluid.GarbageCollection.RunSweep";
/** Config key to turn GC test mode on / off. */
exports.gcTestModeKey = "Fluid.GarbageCollection.GCTestMode";
/** Config key to expire a session after a set period of time. Defaults to true. */
exports.runSessionExpiryKey = "Fluid.GarbageCollection.RunSessionExpiry";
/** Config key to disable the tombstone feature, i.e., tombstone information is not read / written into summary. */
exports.disableTombstoneKey = "Fluid.GarbageCollection.DisableTombstone";
/** Config key to override throwing an error when tombstone object is loaded (requested). */
exports.throwOnTombstoneLoadOverrideKey = "Fluid.GarbageCollection.ThrowOnTombstoneLoadOverride";
/** Config key to enable throwing an error when tombstone object is used (e.g. outgoing or incoming ops). */
exports.throwOnTombstoneUsageKey = "Fluid.GarbageCollection.ThrowOnTombstoneUsage";
/** Config key to enable GC version upgrade. */
exports.gcVersionUpgradeToV4Key = "Fluid.GarbageCollection.GCVersionUpgradeToV4";
/** Config key to disable GC sweep for datastores. They'll merely be Tombstoned. */
exports.disableDatastoreSweepKey = "Fluid.GarbageCollection.DisableDataStoreSweep";
/** Config key to revert new paradigm of detecting outbound routes in ContainerRuntime layer (use true) */
exports.detectOutboundRoutesViaDDSKey = "Fluid.GarbageCollection.DetectOutboundRoutesViaDDS";
/** Config key to disable auto-recovery mechanism that protects Tombstones that are loaded from being swept (use true) */
exports.disableAutoRecoveryKey = "Fluid.GarbageCollection.DisableAutoRecovery";
// One day in milliseconds.
exports.oneDayMs = 1 * 24 * 60 * 60 * 1000;
/**
 * The maximum snapshot cache expiry in the driver. This is used to calculate the tombstone timeout.
 * Tombstone timeout = session expiry timeout + snapshot cache expiry timeout + a buffer.
 * The snapshot cache expiry timeout cannot be known precisely but the upper bound is 5 days, i.e., any snapshot
 * in cache will be invalidated before 5 days.
 */
exports.maxSnapshotCacheExpiryMs = 5 * exports.oneDayMs;
exports.defaultInactiveTimeoutMs = 7 * exports.oneDayMs; // 7 days
exports.defaultSessionExpiryDurationMs = 30 * exports.oneDayMs; // 30 days
exports.defaultSweepGracePeriodMs = 1 * exports.oneDayMs; // 1 day
/**
 * The types of GC nodes in the GC reference graph.
 * @alpha
 */
exports.GCNodeType = {
    // Nodes that are for data stores.
    DataStore: "DataStore",
    // Nodes that are within a data store. For example, DDS nodes.
    SubDataStore: "SubDataStore",
    // Nodes that are for attachment blobs, i.e., blobs uploaded via BlobManager.
    Blob: "Blob",
    // Nodes that are neither of the above. For example, root node.
    Other: "Other",
};
/**
 * The type of a garbage collection message.
 * @internal
 */
exports.GarbageCollectionMessageType = {
    /** Message sent directing GC to delete the given nodes */
    Sweep: "Sweep",
    /** Message sent notifying GC that a Tombstoned object was Loaded */
    TombstoneLoaded: "TombstoneLoaded",
};
/** The state of node that is unreferenced. */
exports.UnreferencedState = {
    /** The node is active, i.e., it can become referenced again. */
    Active: "Active",
    /** The node is inactive, i.e., it should not become referenced. */
    Inactive: "Inactive",
    /** The node is ready to be tombstoned */
    TombstoneReady: "TombstoneReady",
    /** The node is ready to be deleted by the sweep phase. */
    SweepReady: "SweepReady",
};
//# sourceMappingURL=gcDefinitions.js.map